==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OcenaOsoby.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class OcenaOsoby extends GenericDPSObject {
    /**
     * OCENA_OSOBY.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * OCENA_OSOBY.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * OCENA_OSOBY.SKALA_OCENY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long skalaOcenyId;

    /**
     * OCENA_OSOBY.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OCENA_OSOBY.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * OCENA_OSOBY.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return OCENA_OSOBY.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * OCENA_OSOBY.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return OCENA_OSOBY.SKALA_OCENY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSkalaOcenyId() {
        return skalaOcenyId;
    }

    /**
     * OCENA_OSOBY.SKALA_OCENY_ID
     *
     * @param skalaOcenyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSkalaOcenyId(Long skalaOcenyId) {
        this.skalaOcenyId = skalaOcenyId;
    }

    /**
     * @return OCENA_OSOBY.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * OCENA_OSOBY.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OcenaOsoby other = (OcenaOsoby) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getSkalaOcenyId() == null ? other.getSkalaOcenyId() == null : this.getSkalaOcenyId().equals(other.getSkalaOcenyId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getSkalaOcenyId() == null) ? 0 : getSkalaOcenyId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", skalaOcenyId=").append(skalaOcenyId);
        sb.append(", data=").append(data);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OcenaOsoby.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class OcenaOsoby extends GenericDPSObject {
    /**
     * OCENA_OSOBY.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * OCENA_OSOBY.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * OCENA_OSOBY.SKALA_OCENY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long skalaOcenyId;

    /**
     * OCENA_OSOBY.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OCENA_OSOBY.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * OCENA_OSOBY.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return OCENA_OSOBY.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * OCENA_OSOBY.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return OCENA_OSOBY.SKALA_OCENY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSkalaOcenyId() {
        return skalaOcenyId;
    }

    /**
     * OCENA_OSOBY.SKALA_OCENY_ID
     *
     * @param skalaOcenyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSkalaOcenyId(Long skalaOcenyId) {
        this.skalaOcenyId = skalaOcenyId;
    }

    /**
     * @return OCENA_OSOBY.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * OCENA_OSOBY.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OcenaOsoby other = (OcenaOsoby) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getSkalaOcenyId() == null ? other.getSkalaOcenyId() == null : this.getSkalaOcenyId().equals(other.getSkalaOcenyId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getSkalaOcenyId() == null) ? 0 : getSkalaOcenyId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", skalaOcenyId=").append(skalaOcenyId);
        sb.append(", data=").append(data);
        sb.append("]");
        return sb.toString();
    }
}
